Module plugin_namespace

Module plugin_namespace 

Resolve plugin namespace from skill file paths by walking ancestors for plugin.json.

Functions

find_plugin_manifest_path
plugin_namespace_for_root_uri
Returns the plugin manifest name defined directly below plugin_root.
plugin_namespace_for_skill_path
Returns the plugin manifest name for the nearest ancestor of path that contains a valid plugin manifest (same name rules as full manifest loading in codex-core).
plugin_namespace_for_skill_uri
Returns the plugin manifest name for the nearest URI ancestor of path.