Resolve plugin namespace from skill file paths by walking ancestors for plugin.json.
Functions
- find_
plugin_ manifest_ path - plugin_
namespace_ for_ root_ uri - Returns the plugin manifest
namedefined directly belowplugin_root. - plugin_
namespace_ for_ skill_ path - Returns the plugin manifest
namefor the nearest ancestor ofpaththat contains a valid plugin manifest (samenamerules as full manifest loading in codex-core). - plugin_
namespace_ for_ skill_ uri - Returns the plugin manifest
namefor the nearest URI ancestor ofpath.